<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>移到頂部</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>移至頂部</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>從收藏中移除</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>從桌面上移除</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>發送到桌面</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>從任務欄上移除</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>發送到任務欄</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消開機自動啟動</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>開機自動啟動</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>使用代理</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>禁用螢幕縮放</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>全螢幕模式</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>安裝</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>我的常用</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>視窗模式</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>網路應用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交溝通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂欣賞</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影片播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>圖形圖像</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>遊戲娛樂</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>辦公學習</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>閱讀翻譯</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>編程開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他應用</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>您確定要移除“%1”嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>最近安裝</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>所有應用</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>自由排序</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>按分類</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>按名稱</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>排序模式</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>控制中心</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>網路應用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交溝通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂欣賞</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影片播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>圖形圖像</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>遊戲娛樂</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>辦公學習</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>閱讀翻譯</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>編程開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他應用</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>啓動器</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>您確定要移除“%1”嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
</context>
</TS>